defmodule PhilomenaWeb.TagController do
  use PhilomenaWeb, :controller

  alias Philomena.{Images.Image, Tags, Tags.Tag}
  alias Philomena.Interactions
  import Ecto.Query

  def index(conn, params) do
    query_string = params["tq"] || "*"

    with {:ok, query} <- Tags.Query.compile(query_string) do
      tags =
        Tag.search_records(
          %{
            query: query,
            size: 250,
            sort: [%{images: :desc}, %{name: :asc}]
          },
          %{conn.assigns.pagination | page_size: 250},
          Tag
        )

      render(conn, "index.html", tags: tags)
    else
      {:error, msg} ->
        render(conn, "index.html", tags: [], error: msg)
    end
  end

  def show(conn, %{"id" => slug}) do
    tag = Tags.get_tag!(slug)

    query = conn.assigns.compiled_filter
    user = conn.assigns.current_user

    images =
      Image.search_records(
        %{
          query: %{
            bool: %{
              must_not: [query, %{term: %{hidden_from_users: true}}],
              must: %{term: %{"namespaced_tags.name": tag.name}}
            }
          },
          sort: %{created_at: :desc}
        },
        conn.assigns.pagination,
        Image |> preload([:tags, :user])
      )

    interactions =
      Interactions.user_interactions(images, user)

    render(conn, "show.html", tag: tag, interactions: interactions, images: images, layout_class: "layout--wide")
  end
end
